# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class GetTableResponse(UniversalBaseModel):
    asset_id: str = pydantic.Field()
    """
    The ID of the spreadsheet asset
    """

    columns: typing.List[typing.Dict[str, str]] = pydantic.Field()
    """
    Array of column objects with name and other metadata
    """

    message: str = pydantic.Field()
    """
    Success message or error description
    """

    rows: typing.List[typing.Dict[str, typing.Optional[typing.Any]]] = pydantic.Field()
    """
    Array of row objects with column names as keys
    """

    success: bool = pydantic.Field()
    """
    Whether the operation was successful
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class AopAsyncExecuteResponseOut(UniversalBaseModel):
    """
    Response model for async AOP execution.
    """

    aop_asset_id: str = pydantic.Field()
    """
    ID of the AOP asset that was executed
    """

    aop_config: typing.Dict[str, typing.Optional[typing.Any]] = pydantic.Field()
    """
    Full configuration of the AOP asset
    """

    aop_title: str = pydantic.Field()
    """
    Title of the AOP asset
    """

    base_prompt: str = pydantic.Field()
    """
    Base prompt of the AOP before user inputs were added
    """

    final_prompt: str = pydantic.Field()
    """
    Final prompt used for execution including user inputs
    """

    message: str = pydantic.Field()
    """
    Status message about the async execution
    """

    status: str = pydantic.Field()
    """
    Status of the execution (always 'started' for async)
    """

    sync_server: str = pydantic.Field()
    """
    Sync server URL used for execution
    """

    thread_id: str = pydantic.Field()
    """
    Unique thread ID for tracking the execution
    """

    trigger_type: str = pydantic.Field()
    """
    Type of trigger that initiated the execution
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ...core.request_options import RequestOptions
from .raw_client import AsyncRawCalendarClient, RawCalendarClient


class CalendarClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawCalendarClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawCalendarClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawCalendarClient
        """
        return self._raw_client

    def list_events(self, *, request_options: typing.Optional[RequestOptions] = None) -> typing.Optional[typing.Any]:
        """
        Coming soon! List calendar events with optional filtering.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Optional[typing.Any]
            Successful Response

        Examples
        --------
        from athena import Athena

        client = Athena(
            api_key="YOUR_API_KEY",
        )
        client.tools.calendar.list_events()
        """
        _response = self._raw_client.list_events(request_options=request_options)
        return _response.data

    def create_event(self, *, request_options: typing.Optional[RequestOptions] = None) -> typing.Optional[typing.Any]:
        """
        Coming soon! Create new calendar events.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Optional[typing.Any]
            Successful Response

        Examples
        --------
        from athena import Athena

        client = Athena(
            api_key="YOUR_API_KEY",
        )
        client.tools.calendar.create_event()
        """
        _response = self._raw_client.create_event(request_options=request_options)
        return _response.data


class AsyncCalendarClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawCalendarClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawCalendarClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawCalendarClient
        """
        return self._raw_client

    async def list_events(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.Optional[typing.Any]:
        """
        Coming soon! List calendar events with optional filtering.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Optional[typing.Any]
            Successful Response

        Examples
        --------
        import asyncio

        from athena import AsyncAthena

        client = AsyncAthena(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.tools.calendar.list_events()


        asyncio.run(main())
        """
        _response = await self._raw_client.list_events(request_options=request_options)
        return _response.data

    async def create_event(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.Optional[typing.Any]:
        """
        Coming soon! Create new calendar events.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Optional[typing.Any]
            Successful Response

        Examples
        --------
        import asyncio

        from athena import AsyncAthena

        client = AsyncAthena(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.tools.calendar.create_event()


        asyncio.run(main())
        """
        _response = await self._raw_client.create_event(request_options=request_options)
        return _response.data
